#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable
version:              1.0.15.1
visibility:           public
id:                   mono-traversable-1.0.15.1-EzQNvlUnxhT4diePDe8JOn
key:                  mono-traversable-1.0.15.1-EzQNvlUnxhT4diePDe8JOn
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  60218b9ee2f41a449ce24c3756504efd
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-8.10.5/site-local/mono-traversable-1.0.15.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/mono-traversable-1.0.15.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/mono-traversable-1.0.15.1
hs-libraries:         HSmono-traversable-1.0.15.1-EzQNvlUnxhT4diePDe8JOn
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    split-0.2.3.4-6NNts3pcZSB6Io5fuJ9m3X text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp
    vector-algorithms-0.8.0.4-LzRASmIxoS1XEaN5EjNPb

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

